==> jc-1.4.0.tar.gz: javax/sql/ConnectionEvent.h <==
// public class javax.sql.ConnectionEvent

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class e4988e4c1a7050ab java_util_EventObject
// @dep_class ab1dd4fbb17c5c6b javax_sql_ConnectionEvent

// header file dependencies
// @dep_header java_util_EventObject

#include "java/util/EventObject.h"

#ifndef _JC_javax_sql_ConnectionEvent_H_
#define _JC_javax_sql_ConnectionEvent_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_sql_SQLException$object;
struct _jc_javax_sql_PooledConnection$object;

// Typedefs
typedef struct _jc_javax_sql_ConnectionEvent$sub_refs	_jc_javax_sql_ConnectionEvent$sub_refs;
typedef struct _jc_javax_sql_ConnectionEvent$sub_nonrefs	_jc_javax_sql_ConnectionEvent$sub_nonrefs;
typedef struct _jc_javax_sql_ConnectionEvent$refs	_jc_javax_sql_ConnectionEvent$refs;
typedef struct _jc_javax_sql_ConnectionEvent$nonrefs	_jc_javax_sql_ConnectionEvent$nonrefs;
typedef struct _jc_javax_sql_ConnectionEvent$object	_jc_javax_sql_ConnectionEvent$object;

typedef struct _jc_javax_sql_ConnectionEvent$fields_struct	_jc_javax_sql_ConnectionEvent$fields_struct;
typedef const struct _jc_javax_sql_ConnectionEvent$vmethods	_jc_javax_sql_ConnectionEvent$vmethods;
typedef const struct _jc_javax_sql_ConnectionEvent$vtable	_jc_javax_sql_ConnectionEvent$vtable;
typedef const struct _jc_javax_sql_ConnectionEvent$vtype	_jc_javax_sql_ConnectionEvent$vtype;

// Class fields structure
struct _jc_javax_sql_ConnectionEvent$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_javax_sql_ConnectionEvent$fields_struct _jc_javax_sql_ConnectionEvent$class_fields;

// Constructors
extern void _jc_javax_sql_ConnectionEvent$method$_init$d809207ef738afd8(_jc_env *, struct _jc_javax_sql_ConnectionEvent$object *, struct _jc_object *);
extern void _jc_javax_sql_ConnectionEvent$method$_init$3e6606f1c1a1739d(_jc_env *, struct _jc_javax_sql_ConnectionEvent$object *, struct _jc_object *, struct _jc_java_sql_SQLException$object *);

// Virtual methods
extern struct _jc_java_sql_SQLException$object *_jc_javax_sql_ConnectionEvent$method$getSQLException$54ab72cbdd58c7e6(_jc_env *, struct _jc_javax_sql_ConnectionEvent$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_sql_ConnectionEvent$method_info$getSQLException$54ab72cbdd58c7e6;

// Virtual methods structure
struct _jc_javax_sql_ConnectionEvent$vmethods {
	struct _jc_java_sql_SQLException$object	*(*getSQLException$54ab72cbdd58c7e6)(_jc_env *, struct _jc_javax_sql_ConnectionEvent$object *);
};

// Vtable
struct _jc_javax_sql_ConnectionEvent$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_EventObject$vmethods	java_util_EventObject;
	_jc_javax_sql_ConnectionEvent$vmethods	javax_sql_ConnectionEvent;
};

// Vtype
struct _jc_javax_sql_ConnectionEvent$vtype {
	_jc_type			type;
	_jc_javax_sql_ConnectionEvent$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_sql_ConnectionEvent$sub_refs {
	struct _jc_java_sql_SQLException$object	*ex;
};

// Reference instance fields (object)
struct _jc_javax_sql_ConnectionEvent$refs {
    _jc_javax_sql_ConnectionEvent$sub_refs	javax_sql_ConnectionEvent;
    _jc_java_util_EventObject$sub_refs	java_util_EventObject;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_sql_ConnectionEvent$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_sql_ConnectionEvent$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_EventObject$sub_nonrefs	java_util_EventObject;
    _jc_javax_sql_ConnectionEvent$sub_nonrefs	javax_sql_ConnectionEvent;
};

// Object instance structure
struct _jc_javax_sql_ConnectionEvent$object {
	_jc_javax_sql_ConnectionEvent$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_sql_ConnectionEvent$vtype	*vtype;
	_jc_javax_sql_ConnectionEvent$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_sql_ConnectionEvent$vtype _jc_javax_sql_ConnectionEvent$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_sql_ConnectionEvent, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_sql_ConnectionEvent$class_object;

#endif	/* _JC_javax_sql_ConnectionEvent_H_ */

==> jc-1.4.6.tar.gz: javax/sql/ConnectionEvent.h <==
// public class javax.sql.ConnectionEvent

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class e4988e4c1a7050ab java_util_EventObject
// @dep_class ab1dd4fbb17c5c6b javax_sql_ConnectionEvent

// header file dependencies
// @dep_header java_util_EventObject

#include "java/util/EventObject.h"

#ifndef _JC_javax_sql_ConnectionEvent_H_
#define _JC_javax_sql_ConnectionEvent_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_sql_SQLException$object;
struct _jc_javax_sql_PooledConnection$object;

// Typedefs
typedef struct _jc_javax_sql_ConnectionEvent$sub_refs	_jc_javax_sql_ConnectionEvent$sub_refs;
typedef struct _jc_javax_sql_ConnectionEvent$sub_nonrefs	_jc_javax_sql_ConnectionEvent$sub_nonrefs;
typedef struct _jc_javax_sql_ConnectionEvent$refs	_jc_javax_sql_ConnectionEvent$refs;
typedef struct _jc_javax_sql_ConnectionEvent$nonrefs	_jc_javax_sql_ConnectionEvent$nonrefs;
typedef struct _jc_javax_sql_ConnectionEvent$object	_jc_javax_sql_ConnectionEvent$object;

typedef struct _jc_javax_sql_ConnectionEvent$fields_struct	_jc_javax_sql_ConnectionEvent$fields_struct;
typedef const struct _jc_javax_sql_ConnectionEvent$vmethods	_jc_javax_sql_ConnectionEvent$vmethods;
typedef const struct _jc_javax_sql_ConnectionEvent$vtable	_jc_javax_sql_ConnectionEvent$vtable;
typedef const struct _jc_javax_sql_ConnectionEvent$vtype	_jc_javax_sql_ConnectionEvent$vtype;

// Class fields structure
struct _jc_javax_sql_ConnectionEvent$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_javax_sql_ConnectionEvent$fields_struct _jc_javax_sql_ConnectionEvent$class_fields;

// Constructors
extern void _jc_javax_sql_ConnectionEvent$method$_init$d809207ef738afd8(_jc_env *, struct _jc_javax_sql_ConnectionEvent$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_javax_sql_ConnectionEvent$method$_init$3e6606f1c1a1739d(_jc_env *, struct _jc_javax_sql_ConnectionEvent$object *, struct _jc_object *, struct _jc_java_sql_SQLException$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_sql_SQLException$object *_jc_javax_sql_ConnectionEvent$method$getSQLException$54ab72cbdd58c7e6(_jc_env *, struct _jc_javax_sql_ConnectionEvent$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_sql_ConnectionEvent$method_info$getSQLException$54ab72cbdd58c7e6;

// Virtual methods structure
struct _jc_javax_sql_ConnectionEvent$vmethods {
	struct _jc_java_sql_SQLException$object	*(*getSQLException$54ab72cbdd58c7e6)(_jc_env *, struct _jc_javax_sql_ConnectionEvent$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_sql_ConnectionEvent$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_EventObject$vmethods	java_util_EventObject;
	_jc_javax_sql_ConnectionEvent$vmethods	javax_sql_ConnectionEvent;
};

// Vtype
struct _jc_javax_sql_ConnectionEvent$vtype {
	_jc_type			type;
	_jc_javax_sql_ConnectionEvent$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_sql_ConnectionEvent$sub_refs {
	struct _jc_java_sql_SQLException$object	*ex;
};

// Reference instance fields (object)
struct _jc_javax_sql_ConnectionEvent$refs {
    _jc_javax_sql_ConnectionEvent$sub_refs	javax_sql_ConnectionEvent;
    _jc_java_util_EventObject$sub_refs	java_util_EventObject;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_sql_ConnectionEvent$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_sql_ConnectionEvent$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_EventObject$sub_nonrefs	java_util_EventObject;
    _jc_javax_sql_ConnectionEvent$sub_nonrefs	javax_sql_ConnectionEvent;
};

// Object instance structure
struct _jc_javax_sql_ConnectionEvent$object {
	_jc_javax_sql_ConnectionEvent$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_sql_ConnectionEvent$vtype	*vtype;
	_jc_javax_sql_ConnectionEvent$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_sql_ConnectionEvent$vtype _jc_javax_sql_ConnectionEvent$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_sql_ConnectionEvent, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_sql_ConnectionEvent$class_object;

#endif	/* _JC_javax_sql_ConnectionEvent_H_ */
